"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DQLExtension = void 0;
exports.DQLLanguage = DQLLanguage;
var lezer_dql_1 = require("@cloudcare/lezer-dql");
var language_1 = require("@codemirror/language");
var complete_1 = require("./complete");
var lint_1 = require("./lint");
function DQLLanguage() {
    return language_1.LRLanguage.define({
        parser: lezer_dql_1.parser,
        languageData: {
            closeBrackets: { brackets: ['(', '[', '{', "'", '"', '`'] },
            commentTokens: { line: '#' },
        },
    });
}
var DQLExtension = /** @class */ (function () {
    function DQLExtension() {
        this.complete = (0, complete_1.newCompleteStrategy)();
        this.lint = (0, lint_1.newLintStrategy)();
        this.enableLinter = true;
        this.enableCompletion = true;
    }
    DQLExtension.prototype.setComplete = function (dqlClent) {
        this.complete = (0, complete_1.newCompleteStrategy)(dqlClent);
        return this;
    };
    DQLExtension.prototype.getComplete = function () {
        return this.complete;
    };
    DQLExtension.prototype.activateCompletion = function (activate) {
        this.enableCompletion = activate;
        return this;
    };
    DQLExtension.prototype.setLinter = function (linter) {
        this.lint = linter;
        return this;
    };
    DQLExtension.prototype.getLinter = function () {
        return this.lint;
    };
    DQLExtension.prototype.activateLinter = function (activate) {
        this.enableLinter = activate;
        return this;
    };
    DQLExtension.prototype.asExtension = function () {
        var _this = this;
        var language = DQLLanguage();
        var extension = [language];
        if (this.enableCompletion) {
            var completion = language.data.of({
                autocomplete: function (context) {
                    return _this.complete.DQL(context);
                },
            });
            extension = extension.concat(completion);
        }
        if (this.enableLinter) {
            extension = extension.concat((0, lint_1.DQLLinter)(this.lint.promQL, this.lint));
        }
        return extension;
    };
    return DQLExtension;
}());
exports.DQLExtension = DQLExtension;
//# sourceMappingURL=dql.js.map