// Copyright 2021 The Prometheus Authors
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
import { EqlRegex, EqlSingle, Neq, NeqRegex, In, NotIn, StringLiteral, Identifier, InFieldValue, FilterExpr, BinaryExpr, } from '@cloudcare/lezer-dql';
import { walkBackward } from './path-finder';
import { Matcher } from '../types';
export const MatcherOp = [EqlSingle, Neq, EqlRegex, NeqRegex];
export const MatherIn = [In, NotIn];
export function createMatcher(labelMatcher, state) {
    const matcher = new Matcher(0, '', state.sliceDoc(labelMatcher.from, labelMatcher.to).slice(1, -1));
    const binaryNode = walkBackward(labelMatcher, BinaryExpr);
    const cursor = binaryNode.cursor();
    if (cursor.next()) {
        do {
            if (cursor.type.id === FilterExpr) {
                if (!cursor.next())
                    return matcher;
                switch (cursor.type.id) {
                    case Identifier: {
                        if (matcher.type === 0) {
                            // 这里说明是左边的,正常情况下，Identifier只能出现在左边
                            matcher.name = state.sliceDoc(cursor.from, cursor.to);
                        }
                        break;
                    }
                    case StringLiteral: {
                        if (matcher.type === 0) {
                            // 这里说明是左边的，因为左边也支持写'host' = 'xxx' 这种
                            matcher.name = state.sliceDoc(cursor.from, cursor.to).slice(1, -1);
                        }
                        break;
                    }
                    case InFieldValue: {
                        break;
                    }
                }
                cursor.parent(); //回到上一层
            }
            else if ([...MatherIn, ...MatcherOp].includes(cursor.type.id)) {
                matcher.type = cursor.type.id;
            }
        } while (cursor.nextSibling());
    }
    return matcher;
}
export function isMatcher(node) {
    var _a, _b, _c;
    // 判断是否是 正常的 match 表达式，比如 a = '' a != '' a =~ '' a !~ '' a in [] a not in []
    const parentNode = node.parent;
    if (!parentNode) {
        return false;
    }
    if (parentNode.type.id === FilterExpr && parentNode.prevSibling && MatcherOp.includes(parentNode.prevSibling.type.id)) {
        // sex = '直男';
        return true;
    }
    else if (parentNode.type.id === InFieldValue &&
        ((_b = (_a = parentNode.parent) === null || _a === void 0 ? void 0 : _a.type) === null || _b === void 0 ? void 0 : _b.id) === FilterExpr &&
        ((_c = parentNode.parent) === null || _c === void 0 ? void 0 : _c.prevSibling) &&
        MatherIn.includes(parentNode.parent.prevSibling.type.id)) {
        return true; // sex in ["a"]
    }
    return false;
}
//# sourceMappingURL=matcher.js.map